==> aksharamukha-1.0.12.tar.gz: aksharamukha-1.0.12/aksharamukha/ScriptMap/EastIndic/Thai.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Thai

# http://www.thai-language.com/ref/vowels

VowelMap =  [
            '\u0E2D',
            '\u0E2D\u0E32',
            '\u0E2D\u0E34',
            '\u0E2D\u0E35',
            '\u0E2D\u0E38',
            '\u0E2D\u0E39',
            '\u0E24',
            '\u0E24\u0E45',
            '\u0E26',
            '\u0E26\u0E45',
            '\u0E40\u0E2D',
            '\u0E44\u0E2D',
            '\u0E42\u0E2D',
            '\u0E40\u0E2D\u0E32',
            ]

SouthVowelMap = [
                '\u0E40\u0E2D\u0E30',
                '\u0E42\u0E2D\u0E30',
                ]

ModernVowelMap = [
                 '\u0E41\u0E2D\u0E30',
                 '\u0E40\u0E2D\u0E32\u0E30',
                 ]

SinhalaVowelMap = [
                  '\u0E41\u0E2D'
                  ]
    
VowelSignMap =  [
                 '\u0E32',
                 '\u0E34',
                 '\u0E35',
                 '\u0E38',
                 '\u0E39',
                 '\u0E3A\u0E24',
                 '\u0E3A\u0E24\u0E45',
                 '\u0E3A\u0E26',
                 '\u0E3A\u0E26\u0E45',
                 '\u0E40',
                 '\u0E44',
                 '\u0E42',
                 '\u0E40\u0E32',
                ]

SouthVowelSignMap = [
                     '\u0E40\u0E30',
                     '\u0E42\u0E30',                    
                    ]

ModernVowelSignMap =[
                     '\u0E41\u0E30',
                     '\u0E40\u0E32\u0E30',
                    ]

SinhalaVowelSignMap = [
                      '\u0E41'
                      ]

AyogavahaMap = [
               '\u0E4D\u02BD',
               '\u0E4D',
               '\u0E2B\u0E4C'
               ]
    
ViramaMap =  [
             '\u0E3A'
             ]

ConsonantMap =  [
                '\u0E01',
                '\u0E02',
                '\u0E04',
                '\u0E06',
                '\u0E07',
                
                '\u0E08',
                '\u0E09',
                '\u0E0A',
                '\u0E0C',
                '\u0E0D',
                
                '\u0E0F',
                '\u0E10',
                '\u0E11',
                '\u0E12',
                '\u0E13',
                
                '\u0E15',
                '\u0E16',
                '\u0E17',
                '\u0E18',
                '\u0E19',
                
                '\u0E1B',
                '\u0E1C',
                '\u0E1E',
                '\u0E20',
                '\u0E21',
                
                '\u0E22',
                '\u0E23',
                '\u0E25',
                '\u0E27',
                
                '\u0E28',
                '\u0E29',
                '\u0E2A',
                '\u0E2B'
                ]

SouthConsonantMap = [
                    '\u0E2C',
                    '\u0E2C\u02BD',
                    '\u0E23\u02BD',
                    '\u0E19\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\u0E01\u02BD',
                     '\u0E02\u02BD',
                     '\u0E04\u02BD',
                     '\u0E0B',
                     '\u0E23\u02BD',
                     '\u0E23\u0E3A\u0E2B\u02BD',
                     '\u0E1F',
                     '\u0E22\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\u0E4D\u0E04\u02BD',
                     '\u0E4D\u0E0A\u02BD',
                     '\u0E4D\u0E11\u02BD',
                     '\u0E4D\u0E17\u02BD',
                     '\u0E4D\u0E1E\u02BD',
                      ]

NuktaMap = [
           '\u02BD'
           ]
    
OmMap = [
        '\u0E42\u0E2D\u0E4D'
        ]

SignMap =[
         '\u0027',
         '\u0E2F',
         '\u0E5A'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']


NumeralMap = [
             '\u0E50',
             '\u0E51',
             '\u0E52',
             '\u0E53',
             '\u0E54',
             '\u0E55',
             '\u0E56',
             '\u0E57',
             '\u0E58',
             '\u0E59',
             ]

==> aksharamukha-1.7.tar.gz: aksharamukha-1.7/aksharamukha/ScriptMap/EastIndic/Thai.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Thai

# http://www.thai-language.com/ref/vowels

VowelMap =  [
            '\u0E2D',
            '\u0E2D\u0E32',
            '\u0E2D\u0E34',
            '\u0E2D\u0E35',
            '\u0E2D\u0E38',
            '\u0E2D\u0E39',
            '\u0E24',
            '\u0E24\u0E45',
            '\u0E26',
            '\u0E26\u0E45',
            '\u0E2D\u0E40',
            '\u0E2D\u0E44',
            '\u0E2D\u0E42',
            '\u0E2D\u0E40\u0E32',
            ]

SouthVowelMap = [
                '\u0E2D\u0E40\u0E30',
                '\u0E2D\u0E42\u0E30',
                ]

ModernVowelMap = [
                 '\u0E2D\u0E41\u0E30',
                 '\u0E2D\u0E40\u0E32\u0E30',
                 ]

SinhalaVowelMap = [
                  '\u0E2D\u0E41'
                  ]

VowelSignMap =  [
                 '\u0E32',
                 '\u0E34',
                 '\u0E35',
                 '\u0E38',
                 '\u0E39',
                 '\u0E3A\u0E24',
                 '\u0E3A\u0E24\u0E45',
                 '\u0E3A\u0E26',
                 '\u0E3A\u0E26\u0E45',
                 '\u0E40',
                 '\u0E44',
                 '\u0E42',
                 '\u0E40\u0E32',
                ]

SouthVowelSignMap = [
                     '\u0E40\u0E30',
                     '\u0E42\u0E30',
                    ]

ModernVowelSignMap =[
                     '\u0E41\u0E30',
                     '\u0E40\u0E32\u0E30',
                    ]

SinhalaVowelSignMap = [
                      '\u0E41'
                      ]

AyogavahaMap = [
               '\u0E4D\u02BD',
               '\u0E4D',
               '\u0E2B\u0E4C'
               ]

ViramaMap =  [
             '\u0E3A'
             ]

ConsonantMap =  [
                '\u0E01',
                '\u0E02',
                '\u0E04',
                '\u0E06',
                '\u0E07',

                '\u0E08',
                '\u0E09',
                '\u0E0A',
                '\u0E0C',
                '\u0E0D',

                '\u0E0F',
                '\u0E10',
                '\u0E11',
                '\u0E12',
                '\u0E13',

                '\u0E15',
                '\u0E16',
                '\u0E17',
                '\u0E18',
                '\u0E19',

                '\u0E1B',
                '\u0E1C',
                '\u0E1E',
                '\u0E20',
                '\u0E21',

                '\u0E22',
                '\u0E23',
                '\u0E25',
                '\u0E27',

                '\u0E28',
                '\u0E29',
                '\u0E2A',
                '\u0E2B'
                ]

SouthConsonantMap = [
                    '\u0E2C',
                    '\u0E2C\u02BD',
                    '\u0E23\u02BD',
                    '\u0E19\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\u0E01\u02BD',
                     'ฃ',
                     'ฅ',
                     '\u0E0B',
                     '\u0E23\u02BD',
                     '\u0E23\u0E3A\u0E2B\u02BD',
                     '\u0E1F',
                     '\u0E22\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\u0E4D\u0E04\u02BD',
                     '\u0E4D\u0E0A\u02BD',
                     '\u0E4D\u0E11\u02BD',
                     '\u0E4D\u0E17\u02BD',
                     '\u0E4D\u0E1E\u02BD',
                      ]

NuktaMap = [
           '\u02BD'
           ]

OmMap = [
        '\u0E42\u0E2D\u0E4D'
        ]

SignMap =[
         '\u0027',
         '\u0E2F',
         '\u0E5A'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']


NumeralMap = [
             '\u0E50',
             '\u0E51',
             '\u0E52',
             '\u0E53',
             '\u0E54',
             '\u0E55',
             '\u0E56',
             '\u0E57',
             '\u0E58',
             '\u0E59',
             ]
